==> tasker-akka-2016.1.10-sources.jar: com/xebialabs/deployit/engine/tasker/TaskStep.java <==
package com.xebialabs.deployit.engine.tasker;

import java.io.Serializable;
import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;
import org.joda.time.DateTime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.xebialabs.deployit.engine.api.execution.StepExecutionState;
import com.xebialabs.deployit.engine.api.execution.StepState;
import com.xebialabs.deployit.plugin.api.flow.Step;

import static com.google.common.collect.Maps.newHashMap;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.EXECUTING;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.FAILED;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.PENDING;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.SKIP;
import static org.joda.time.DateTimeZone.UTC;

@SuppressWarnings("serial")
public class TaskStep implements StepState, Serializable {

    public static final String ERROR_PREFIX = "[ERROR]: ";

    private final Step implementation;
    private final Map<String, String> metadata = newHashMap();
    private final boolean skippable;
    private volatile StepExecutionState state;
    private transient Thread runningThread;
    private AtomicInteger failureCount;
    StringBuilder logBuilder;
    private DateTime startDate;
    private DateTime completionDate;
    private DateTime lastModificationDate;
    private String description;

    public TaskStep(Step step) {
        this.implementation = step;
        this.state = StepExecutionState.PENDING;
        this.failureCount = new AtomicInteger();
        this.logBuilder = new StringBuilder();
        this.description = step.getDescription();
        this.skippable = step.skippable();
    }

    @SuppressWarnings("rawtypes")
    public Step getImplementation() {
        return implementation;
    }

    void setState(StepExecutionState state) {
        this.state = state;
        if (state == FAILED) {
            failureCount.incrementAndGet();
        }
        touch();
    }

    void recordStart() {
        this.startDate = new DateTime(UTC);
        touch();
    }

    void recordCompletion() {
        this.completionDate = new DateTime(UTC);
        touch();
    }

    void clearLog() {
        logBuilder.setLength(0);
    }

    void touch() {
        this.lastModificationDate = new DateTime(UTC);
    }

    public boolean isMarkedForSkip() {
        return getState() == SKIP;
    }

    public boolean canSkip() {
        return this.skippable && (getState() == PENDING || getState() == FAILED || getState() == SKIP);
    }

    public boolean hasExecuted() {
        return state == StepExecutionState.DONE || state == StepExecutionState.SKIPPED;
    }

    @Override
    public String toString() {
        return "[" + description + "]";
    }

    @Override
    public StepExecutionState getState() {
        return state;
    }

    @Override
    public String getLog() {
        return logBuilder.toString();
    }

    @Override
    public String getDescription() {
        return description;
    }

    @Override
    public DateTime getStartDate() {
        return startDate;
    }

    @Override
    public DateTime getCompletionDate() {
        return completionDate;
    }

    public DateTime getLastModificationDate() {
        return lastModificationDate;
    }

    @Override
    public int getFailureCount() {
        return failureCount.intValue();
    }

    public void setRunner() {
        runningThread = Thread.currentThread();
        logger.debug("Setting the thread {}", runningThread.getId());
    }

    public void interruptRunner() {
        logger.debug("Trying to interrupt task step {}", description);
        if (runningThread != null) {
            logger.debug("Interrupting the running thread {}", runningThread.getId());
            runningThread.interrupt();
        }
    }

    @Override
    public Map<String, String> getMetadata() {
        return metadata;
    }

    @Override
    public boolean getSkippable() {
        return this.skippable;
    }

    public boolean isFailed() {
        return getState() == FAILED;
    }

    public TaskStep recovered() {
        if (state == EXECUTING) {
            setState(FAILED);
        }
        return this;
    }

    static final Logger logger = LoggerFactory.getLogger(TaskStep.class);
}

==> tasker-akka-2017.1.0-sources.jar: com/xebialabs/deployit/engine/tasker/TaskStep.java <==
package com.xebialabs.deployit.engine.tasker;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;
import org.joda.time.DateTime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.xebialabs.deployit.engine.api.execution.StepExecutionState;
import com.xebialabs.deployit.engine.api.execution.StepState;
import com.xebialabs.deployit.plugin.api.flow.Step;

import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.EXECUTING;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.FAILED;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.PENDING;
import static com.xebialabs.deployit.engine.api.execution.StepExecutionState.SKIP;
import static org.joda.time.DateTimeZone.UTC;

@SuppressWarnings("serial")
public class TaskStep implements StepState, Serializable {

    public static final String ERROR_PREFIX = "[ERROR]: ";

    private final Step implementation;
    private final Map<String, String> metadata = new HashMap<>();
    private volatile StepExecutionState state;
    private transient Thread runningThread;
    private AtomicInteger failureCount;
    StringBuilder logBuilder;
    private DateTime startDate;
    private DateTime completionDate;
    private DateTime lastModificationDate;
    private String description;

    public TaskStep(Step step) {
        this.implementation = step;
        this.state = StepExecutionState.PENDING;
        this.failureCount = new AtomicInteger();
        this.logBuilder = new StringBuilder();
        this.description = step.getDescription();
    }

    @SuppressWarnings("rawtypes")
    public Step getImplementation() {
        return implementation;
    }

    void setState(StepExecutionState state) {
        this.state = state;
        if (state == FAILED) {
            failureCount.incrementAndGet();
        }
        touch();
    }

    void recordStart() {
        this.startDate = new DateTime(UTC);
        touch();
    }

    void recordCompletion() {
        this.completionDate = new DateTime(UTC);
        touch();
    }

    void clearLog() {
        logBuilder.setLength(0);
    }

    void touch() {
        this.lastModificationDate = new DateTime(UTC);
    }

    public boolean isMarkedForSkip() {
        return getState() == SKIP;
    }

    // FIXME Write test for Unskippable
    public boolean canSkip() {
        return (getState() == PENDING || getState() == FAILED || getState() == SKIP);
    }

    public boolean hasExecuted() {
        return state == StepExecutionState.DONE || state == StepExecutionState.SKIPPED;
    }

    @Override
    public String toString() {
        return "[" + description + "]";
    }

    @Override
    public StepExecutionState getState() {
        return state;
    }

    @Override
    public String getLog() {
        return logBuilder.toString();
    }

    @Override
    public String getDescription() {
        return description;
    }

    @Override
    public DateTime getStartDate() {
        return startDate;
    }

    @Override
    public DateTime getCompletionDate() {
        return completionDate;
    }

    public DateTime getLastModificationDate() {
        return lastModificationDate;
    }

    @Override
    public int getFailureCount() {
        return failureCount.intValue();
    }

    public void registerCurrentThread() {
        runningThread = Thread.currentThread();
        logger.debug("Setting the thread {}", runningThread.getId());
    }

    public void interruptRunner() {
        logger.debug("Trying to interrupt task step {}", description);
        if (runningThread != null) {
            logger.debug("Interrupting the running thread {}", runningThread.getId());
            runningThread.interrupt();
        }
    }

    @Override
    public Map<String, String> getMetadata() {
        return metadata;
    }

    public boolean isFailed() {
        return getState() == FAILED;
    }

    public TaskStep recovered() {
        if (state == EXECUTING) {
            setState(FAILED);
        }
        return this;
    }

    static final Logger logger = LoggerFactory.getLogger(TaskStep.class);
}
